@@ -1,11 +1,11 @@
-from __future__ import absolute_import, unicode_literals
+import os
 from datetime import datetime, timedelta
-from io import BytesIO
 
-from stravalib import model, exc, attributes, unithelper as uh
-from stravalib.client import Client
+from stravalib import model, exc, unithelper as uh
+from stravalib.tests import RESOURCES_DIR
 from stravalib.tests.functional import FunctionalTestBase
 
+
 class ClientWriteTest(FunctionalTestBase):
     
     def test_create_activity(self):
@@ -18,14 +18,13 @@ class ClientWriteTest(FunctionalTestBase):
                                         start_date_local=now,
                                         elapsed_time=timedelta(hours=3, minutes=4, seconds=5),
                                         distance=uh.miles(15.2))
-        print a
+        print(a)
         
         self.assertIsInstance(a, model.Activity)
-        self.assertEquals("test_create_activity#simple", a.name)
-        self.assertEquals(now, a.start_date_local)
-        self.assertEquals(round(float(uh.miles(15.2)), 2), round(float(uh.miles(a.distance)), 2))
-        self.assertEquals(timedelta(hours=3, minutes=4, seconds=5), a.elapsed_time)
-    
+        self.assertEqual("test_create_activity#simple", a.name)
+        self.assertEqual(now, a.start_date_local)
+        self.assertEqual(round(float(uh.miles(15.2)), 2), round(float(uh.miles(a.distance)), 2))
+        self.assertEqual(timedelta(hours=3, minutes=4, seconds=5), a.elapsed_time)
     
     def test_update_activity(self):
         """
@@ -39,10 +38,10 @@ class ClientWriteTest(FunctionalTestBase):
                                         distance=uh.miles(15.2))
         
         self.assertIsInstance(a, model.Activity)
-        self.assertEquals("test_update_activity#create", a.name)
+        self.assertEqual("test_update_activity#create", a.name)
         
         update1 = self.client.update_activity(a.id, name="test_update_activivty#update")
-        self.assertEquals("test_update_activivty#update", update1.name)
+        self.assertEqual("test_update_activivty#update", update1.name)
         self.assertFalse(update1.private)
         self.assertFalse(update1.trainer)
         self.assertFalse(update1.commute)
@@ -54,8 +53,6 @@ class ClientWriteTest(FunctionalTestBase):
         self.assertTrue(update3.private)
         self.assertTrue(update3.trainer)
         
-        
-        
     def test_upload_activity(self):
         """
         Test uploading an activity.
@@ -69,7 +66,7 @@ class ClientWriteTest(FunctionalTestBase):
             a = uploader.wait()
             self.assertTrue(uploader.is_complete)
             self.assertIsInstance(a, model.Activity)
-            self.assertEquals("02/21/2009 Leiden, ZH, The Netherlands", a.name)
+            self.assertEqual("02/21/2009 Leiden, ZH, The Netherlands", a.name)
             
             # And we'll get an error if we try the same file again
             with self.assertRaises(exc.ActivityUploadFailed):
