@@ -1,4 +1,3 @@
-from __future__ import division, absolute_import, print_function, unicode_literals
 import functools
 
 from stravalib import model
@@ -17,7 +16,7 @@ class ResultIteratorTest(FunctionalTestBase):
         result_fetcher = functools.partial(self.protocol.get, '/athlete/activities')
         results = BatchedResultsIterator(entity=model.Activity, result_fetcher=result_fetcher, limit=10, per_page=2)
         results = list(results)
-        self.assertEquals(10, len(results))
+        self.assertEqual(10, len(results))
     
     def test_multiple_iterator_calls(self):
         """ Test multiple calls of the iterator. """
@@ -28,8 +27,8 @@ class ResultIteratorTest(FunctionalTestBase):
         results1 = list(results)
         results2 = list(results)
         
-        self.assertEquals(10, len(results1))
-        self.assertEquals(len(results1), len(results2))
+        self.assertEqual(10, len(results1))
+        self.assertEqual(len(results1), len(results2))
     
     
     def test_limit_iterator(self):
@@ -39,7 +38,7 @@ class ResultIteratorTest(FunctionalTestBase):
         results = BatchedResultsIterator(entity=model.Activity, result_fetcher=result_fetcher, limit=10, per_page=2)
         results.limit = 10
         results = list(results)
-        self.assertEquals(10, len(results))
+        self.assertEqual(10, len(results))
             
         
         # TODO: use a mock here to figure out how many calls are happening under the hood.
@@ -52,5 +51,5 @@ class ResultIteratorTest(FunctionalTestBase):
         
         ri = BatchedResultsIterator(entity=model.Shoe, result_fetcher=pretend_fetcher)
         results = list(ri)
-        self.assertEquals(0, len(results))
+        self.assertEqual(0, len(results))
     
\ No newline at end of file
